@@ -30,6 +30,7 @@
 
 #include <cmd.h>
 #include <dialog.h>
+#include <version.h>
 
 
 namespace Ui {
@@ -44,8 +45,7 @@ public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
-    QString getVersion(QString name) const;
-    QString selectPartiton(QStringList list);
+    QString selectPartiton(const QStringList &list);
     QStringList getLinuxPartitions();
 
     void addGrubArg(const QString &key, const QString &item);
